@@ -1,6 +1,6 @@
 package Bot::Cobalt::Plugin::Twitter;
 # ABSTRACT: Bot::Cobalt plugin for automatic tweeting
-$Bot::Cobalt::Plugin::Twitter::VERSION = '0.002';
+$Bot::Cobalt::Plugin::Twitter::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -18,6 +18,7 @@ my $status_rx = qr/twitter\.com\/\w+\/status\/(\d+)/;
 sub new     { bless {}, shift  }
 sub twitter { shift->{twitter} }
 
+sub display_tweets { shift->{display_tweets} }
 sub tweet_topics   { shift->{tweet_topics}   }
 sub tweet_links    { shift->{tweet_links}    } 
 sub retweet_tweets { shift->{retweet_tweets} }
@@ -28,7 +29,8 @@ sub Cobalt_register {
    my $core = shift;
    my $conf = $core->get_plugin_cfg($self);
 
-   $self->{tweet_topics}   = $conf->{tweet_topics} // 1;
+   $self->{display_tweets} = $conf->{display_tweets} // 1;
+   $self->{tweet_topics}   = $conf->{tweet_topics}   // 1;
    $self->{tweet_links}    = $conf->{tweet_links};
    $self->{retweet_tweets} = $conf->{retweet_tweets};
    $self->{useragent}      = Mojo::UserAgent->new;
@@ -103,7 +105,8 @@ sub Bot_public_msg {
    my $core = shift;
    my $msg  = ${ shift() };
 
-   return PLUGIN_EAT_NONE unless $self->tweet_links or $self->retweet_tweets;
+   return PLUGIN_EAT_NONE 
+	unless $self->display_tweets or $self->tweet_links or $self->retweet_tweets;
 
    my $context = $msg->context;
    my $channel = $msg->target;
@@ -122,24 +125,26 @@ sub Bot_public_msg {
             }
          }
          
-         my $tweet = $self->twitter->show_status($id);
-         my $text  = $tweet->{text};
-         my $name  = $tweet->{user}->{name};
-         my $sname = $tweet->{user}->{screen_name};
-         my $user  = sprintf '%s (@%s)', $name, $sname;
+         if ($self->display_tweets) {   
+            my $tweet = $self->twitter->show_status($id);
+            my $text  = $tweet->{text};
+            my $name  = $tweet->{user}->{name};
+            my $sname = $tweet->{user}->{screen_name};
+            my $user  = sprintf '%s (@%s)', $name, $sname;
          
-         $text = unidecode(decode_entities($text));
-         my @lines  = split /\n/, $text;
+            $text = unidecode(decode_entities($text));
+            my @lines  = split /\n/, $text;
 
-         if (@lines == 1) {
-            broadcast( 'message', $context, $channel, "$user - $lines[0]" );
+            if (@lines == 1) {
+               broadcast( 'message', $context, $channel, "$user - $lines[0]" );
+            }
+            else {
+               broadcast( 'message', $context, $channel, $user );
+               broadcast( 'message', $context, $channel, " - $_" )
+                  foreach @lines;
+            }
+            return PLUGIN_EAT_ALL;
          }
-         else {
-            broadcast( 'message', $context, $channel, $user );
-            broadcast( 'message', $context, $channel, " - $_" )
-               foreach @lines;
-         }
-         return PLUGIN_EAT_ALL;
       }
       elsif ($self->tweet_links) {
          my $title = $self->ua->get($uri)->result->dom->at('title')->text;
@@ -182,7 +187,7 @@ Bot::Cobalt::Plugin::Twitter - Bot::Cobalt plugin for automatic tweeting
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -191,6 +196,7 @@ version 0.002
       Module: Bot::Cobalt::Plugin::Twitter
       Config: plugins/twitter.conf
       Opts:
+         display_tweets: 1
          retweet_tweets: 0
          tweet_links: 0
          tweet_topics: 1
@@ -211,6 +217,10 @@ Additionally, it does a handful of twitter-related functions.
 
 =over 4
 
+=item display_tweets (default: on)
+
+Whenever a twitter status link is said in chat, look it up and display it.
+
 =item tweet_links (default: off)
 
 Whenever a link is tweeted, tweet it (with title).
